SignificaUtils.HealthController (significa_utils v0.3.0)
View SourceInternal controller to be used by SignificaUtils.HealthRouter.
Summary
Functions
Route handler that returns the version of the latest ecto migration (table schema_migrations).
Uses the repo specified when using SignificaUtils.HealthRouter.
Route handler that always returns "OK"
Route handler that returns the value of the Application env :app_version for the otp_app
specified when using SignificaUtils.HealthRouter.
Functions
Route handler that returns the version of the latest ecto migration (table schema_migrations).
Uses the repo specified when using SignificaUtils.HealthRouter.
Route handler that always returns "OK"
Route handler that returns the value of the Application env :app_version for the otp_app
specified when using SignificaUtils.HealthRouter.